==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/mn/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Хэрэглэгч вэбсайт дээрх зүйл хүсэлтийг цуцалсан байна',
    'a_user_requested' => 'Хэрэглэгч вэбсайт дээрх зүйлийг хүссэн байна',
    'accessory_name' => 'Дагалдах хэрэгслийн нэр:',
    'additional_notes' => 'Нэмэлт тайлбар:',
    'admin_has_created' => 'Администратор танд зориулж дараах вэбсайт дээр акаунт үүсгэсэн байна.',
    'asset' => 'Актив:',
    'asset_name' => 'Хөрөнгийн нэр:',
    'asset_requested' => 'Хөрөнгө хүссэн',
    'asset_tag' => 'Хөрөнгийн тэмдэг:',
    'assigned_to' => 'Томилогдсон',
    'best_regards' => 'Хамгийн сайн нь,',
    'canceled' => 'Цуцалсан:',
    'checkin_date' => 'Огноо шалгах:',
    'checkout_date' => 'Тооцоо хийх өдөр:',
    'click_to_confirm' => 'Вэбсайтаа баталгаажуулахын тулд дараах холбоос дээр дарна уу:',
    'click_on_the_link_accessory' => 'Дагалдах хэрэгслийг хүлээн авсан гэдгээ батлахын тулд доорх холбоос дээр дарна уу.',
    'click_on_the_link_asset' => 'Хөрөнгийг хүлээн авсан гэдгээ батлахын тулд доорх холбоос дээр дарна уу.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Одоогийн QTY',
    'Days' => 'Өдөр',
    'days' => 'Өдөр',
    'expecting_checkin_date' => 'Хүлээгдэж буй хугацаа:',
    'expires' => 'Хугацаа дуусна',
    'Expiring_Assets_Report' => 'Хугацаа дууссан активын тайлан.',
    'Expiring_Licenses_Report' => 'Хугацаа дуусгавар болсон лицензийн тайлан.',
    'hello' => 'Сайн уу',
    'hi' => 'Сайн уу',
    'i_have_read' => 'Би ашиглалтын нөхцөлийг уншиж, зөвшөөрч, энэ зүйлийг хүлээн авсан.',
    'item' => 'Зүйл:',
    'Item_Request_Canceled' => 'Зүйлийн хүсэлтийг хүчингүй болгох',
    'Item_Requested' => 'Барааны хүсэлт',
    'link_to_update_password' => 'Вэбсайтаа шинэчлэхийн тулд дараах холбоос дээр дарна уу:',
    'login_first_admin' => 'Слайд-IT-г суулгахын тулд доорх итгэмжлэлүүдийг ашиглана уу:',
    'login' => 'Нэвтрэх:',
    'Low_Inventory_Report' => 'Бага нөөцийн тайлан',
    'min_QTY' => 'Min QTY',
    'name' => 'Нэр',
    'new_item_checked' => 'Таны нэрээр шинэ зүйл шалгасан бөгөөд дэлгэрэнгүй мэдээлэл доор байна.',
    'password' => 'Нууц үг:',
    'password_reset' => 'Нууц үг шинэчлэх',

    'read_the_terms' => 'Доорх хэрэглээний нөхцөлийг уншина уу.',
    'read_the_terms_and_click' => 'Доорх хэрэглээний нөхцөлийг уншина уу, доод тал дээрх холбоос дээр дарж уншсанаа баталгаажуулж, ашиглалтын нөхцөлийг хүлээн зөвшөөрч, уг хөрөнгийг хүлээн авсан болно.',
    'requested' => 'Хүсэлт гаргасан:',
    'reset_link' => 'Таны нууц үгээ шинэчлэх линк',
    'reset_password' => 'Нууц үгээ дахин тохируулах бол энд дарна уу:',
    'serial' => 'Сериал',
    'supplier' => 'Нийлүүлэгч',
    'tag' => 'Таг',
    'test_email' => 'Слайк-IT-с тест хийх мэйл',
    'test_mail_text' => 'Энэ бол Snipe-IT Asset Management System-ийн тест юм. Хэрэв та үүнийг авсан бол имэйл ажиллаж байна :)',
    'the_following_item' => 'Дараах зүйлүүдийг шалгасан байна:',
    'low_inventory_alert' => ':count ширхэг барааны нөөц дуусаж байна.|:count ширхэг барааны нөөц дуусаж байна.',
    'assets_warrantee_alert' => ':count ширхэг хөрөнгийн баталгаат хугацаа :threshhold өдрийн дотор дуусна.|:count ширхэг хөрөнгийн баталгаат хугацаа :threshhold өдрийн дотор дуусна.',
    'license_expiring_alert' => ':count ширхэг лизенц :threshhold өдрийн дотор дуусна.|:count ширхэг лизенц :threshhold өдрийн дотор дуусна.',
    'to_reset' => 'Та өөрийн: веб нууц үгээ шинэчлэхийн тулд энэ маягтыг бөглөнө үү:',
    'type' => 'Төрөл',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Хэрэглэгч',
    'username' => 'Нэвтрэх нэр',
    'welcome' => 'Тавтай морилно уу: нэр',
    'welcome_to' => 'Тавтай морилно уу: Вэб хуудас!',
    'your_credentials' => 'Таны Snipe-IT итгэмжлэлүүд',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/mn/mail.php <==
<?php

return [
    'a_user_canceled' => 'Хэрэглэгч вэбсайт дээрх зүйл хүсэлтийг цуцалсан байна',
    'a_user_requested' => 'Хэрэглэгч вэбсайт дээрх зүйлийг хүссэн байна',
    'accessory_name' => 'Дагалдах хэрэгслийн нэр:',
    'additional_notes' => 'Нэмэлт тайлбар:',
    'admin_has_created' => 'Администратор танд зориулж дараах вэбсайт дээр акаунт үүсгэсэн байна.',
    'asset' => 'Актив:',
    'asset_name' => 'Хөрөнгийн нэр:',
    'asset_requested' => 'Хөрөнгө хүссэн',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Томилогдсон',
    'best_regards' => 'Хамгийн сайн нь,',
    'canceled' => 'Цуцалсан:',
    'checkin_date' => 'Огноо шалгах:',
    'checkout_date' => 'Тооцоо хийх өдөр:',
    'click_to_confirm' => 'Вэбсайтаа баталгаажуулахын тулд дараах холбоос дээр дарна уу:',
    'click_on_the_link_accessory' => 'Дагалдах хэрэгслийг хүлээн авсан гэдгээ батлахын тулд доорх холбоос дээр дарна уу.',
    'click_on_the_link_asset' => 'Хөрөнгийг хүлээн авсан гэдгээ батлахын тулд доорх холбоос дээр дарна уу.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Одоогийн QTY',
    'Days' => 'Өдөр',
    'days' => 'Өдөр',
    'expecting_checkin_date' => 'Хүлээгдэж буй хугацаа:',
    'expires' => 'Хугацаа дуусна',
    'Expiring_Assets_Report' => 'Хугацаа дууссан активын тайлан.',
    'Expiring_Licenses_Report' => 'Хугацаа дуусгавар болсон лицензийн тайлан.',
    'hello' => 'Сайн уу',
    'hi' => 'Сайн уу',
    'i_have_read' => 'Би ашиглалтын нөхцөлийг уншиж, зөвшөөрч, энэ зүйлийг хүлээн авсан.',
    'item' => 'Зүйл:',
    'Item_Request_Canceled' => 'Зүйлийн хүсэлтийг хүчингүй болгох',
    'Item_Requested' => 'Барааны хүсэлт',
    'link_to_update_password' => 'Вэбсайтаа шинэчлэхийн тулд дараах холбоос дээр дарна уу:',
    'login_first_admin' => 'Слайд-IT-г суулгахын тулд доорх итгэмжлэлүүдийг ашиглана уу:',
    'login' => 'Нэвтрэх:',
    'Low_Inventory_Report' => 'Бага нөөцийн тайлан',
    'min_QTY' => 'Min QTY',
    'name' => 'Нэр',
    'new_item_checked' => 'Таны нэрээр шинэ зүйл шалгасан бөгөөд дэлгэрэнгүй мэдээлэл доор байна.',
    'password' => 'Нууц үг:',
    'password_reset' => 'Нууц үг шинэчлэх',

    'read_the_terms' => 'Доорх хэрэглээний нөхцөлийг уншина уу.',
    'read_the_terms_and_click' => 'Доорх хэрэглээний нөхцөлийг уншина уу, доод тал дээрх холбоос дээр дарж уншсанаа баталгаажуулж, ашиглалтын нөхцөлийг хүлээн зөвшөөрч, уг хөрөнгийг хүлээн авсан болно.',
    'requested' => 'Хүсэлт гаргасан:',
    'reset_link' => 'Таны нууц үгээ шинэчлэх линк',
    'reset_password' => 'Нууц үгээ дахин тохируулах бол энд дарна уу:',
    'serial' => 'Сериал',
    'supplier' => 'Нийлүүлэгч',
    'tag' => 'Таг',
    'test_email' => 'Слайк-IT-с тест хийх мэйл',
    'test_mail_text' => 'Энэ бол Snipe-IT Asset Management System-ийн тест юм. Хэрэв та үүнийг авсан бол имэйл ажиллаж байна :)',
    'the_following_item' => 'Дараах зүйлүүдийг шалгасан байна:',
    'low_inventory_alert' => ':count ширхэг барааны нөөц дуусаж байна.|:count ширхэг барааны нөөц дуусаж байна.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => ':count ширхэг лизенц :threshhold өдрийн дотор дуусна.|:count ширхэг лизенц :threshhold өдрийн дотор дуусна.',
    'to_reset' => 'Та өөрийн: веб нууц үгээ шинэчлэхийн тулд энэ маягтыг бөглөнө үү:',
    'type' => 'Төрөл',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Хэрэглэгч',
    'username' => 'Нэвтрэх нэр',
    'welcome' => 'Тавтай морилно уу: нэр',
    'welcome_to' => 'Тавтай морилно уу: Вэб хуудас!',
    'your_credentials' => 'Таны Snipe-IT итгэмжлэлүүд',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
];
